from .misspelling_lib.misspelling_detector import MisspellingDetector
from .misspelling_lib.misspelling_factory import MisspellingFactory

__all__ = [
    "MisspellingDetector",
    "MisspellingFactory",
]



#!/usr/bin/env python
"""
Checks files against a list of commonly misspelled words.

Wikipedia contains a large number of proper nouns and technical
terms. Traditional spell-checking in this case is problematic.
Instead, it has a page that people can use to list commonly misspelled
words and to then use that to find misspellings.

A similar approach can be taken to spell-checking (or misspell-checking)
the files in a body of source code.

This tool uses the English wordlist from Wikipedia in order to scan
source code and identify misspelled words.
"""

import codecs
import sys
from pathlib import Path
from typing import Optional

from rich.console import Console

file = Path(__file__).resolve()
package_root_directory = file.parent.parent
sys.path.append(str(package_root_directory))


from misspelling_lib import MisspellingFactory
from misspelling_lib.utils import MisspellingArgumentParser, expand_directories, get_version, parse_file_list


def main() -> Optional[int]:
    """Internal main entry point."""
    parser = MisspellingArgumentParser()
    args = parser.parse_args()

    if args.file_list:
        try:
            args.files += parse_file_list(args.file_list)
        except IOError as exception:
            parser.error(exception)

    output = codecs.getwriter("utf-8")(sys.stdout.buffer if hasattr(sys.stdout, "buffer") else sys.stdout)

    if args.version:
        console = Console()
        console.print(f"[green]misspellings version[/green]: [bold green]{get_version()}")
        return 0

    if args.misspelling_file:
        misspelling = MisspellingFactory.factory(
            misspelling_detector_name="misspelling_file_detector",
            misspelling_file=args.misspelling_file,
        )
        args.files = expand_directories(args.files)

        if args.export_file:
            with open(args.export_file, "w", encoding="utf-8") as correction_file:
                misspelling.export_result_to_file(filenames=args.files, output=correction_file)
    elif args.json_file:
        misspelling = MisspellingFactory.factory(
            misspelling_detector_name="misspelling_json_detector",
            misspelling_file=args.json_file,
        )
        args.files = expand_directories(args.files)

        if args.export_file:
            with open(args.export_file, "w", encoding="utf-8") as correction_file:
                misspelling.export_result_to_file(filenames=args.files, output=correction_file)
    else:
        misspelling = MisspellingFactory.factory(misspelling_detector_name="misspelling_detector")
        args.files = expand_directories(args.files)

        if args.export_file:
            with open(args.export_file, "w", encoding="utf-8") as correction_file:
                misspelling.export_result_to_file(filenames=args.files, output=correction_file)

    if args.dump_misspelling:
        for word, correction in misspelling.dump_corrections():
            output.write("%s %s\n" % (word, correction))

    if args.script_output:
        misspelling.output_sed_commands(parser, args, filenames=args.files)
        return 0

    return 2 if misspelling.print_result(filenames=args.files, output=output) else 0


if __name__ == "__main__":
    sys.exit(main())



from pathlib import Path
from typing import Any, Dict, Optional, Union

from .misspelling_detector import MisspellingDetector
from .misspelling_file_detector import MisspellingFileDetector
from .misspelling_json_detector import MisspellingJSONDetector

MisspellingDetectorType = Union[MisspellingDetector, MisspellingFileDetector, MisspellingJSONDetector]


class MisspellingFactory:
    @classmethod
    def factory(
        cls, misspelling_detector_name: str, misspelling_file: Optional[Union[Path, None]] = None
    ) -> MisspellingDetectorType:
        class_map = cls.get_misspelling_class_map()
        if misspelling_detector_name == "misspelling_detector":
            return class_map.get(misspelling_detector_name)()
        return class_map.get(misspelling_detector_name)(misspelling_file)

    @staticmethod
    def get_misspelling_class_map() -> Dict[str, Any]:
        return {
            "misspelling_detector": MisspellingDetector,
            "misspelling_file_detector": MisspellingFileDetector,
            "misspelling_json_detector": MisspellingJSONDetector,
        }



#!/usr/bin/env python

"""
Installer for misspelling-check.
This installs the misspellings command.
"""

import sys
import unittest
from pathlib import Path

from setuptools import Command, find_packages, setup

from src.misspelling_lib.utils import get_version

this_directory = Path(__file__).parent
long_description = (this_directory / "README.md").read_text()


class TestCommand(Command):
    description = "Runs all available tests."
    user_options = []

    def initialize_options(self):
        pass

    def finalize_options(self):
        pass

    def run(self):
        tests = unittest.TestLoader().discover("tests")
        runner = unittest.TextTestRunner(verbosity=2)
        result = runner.run(tests)
        if not result.wasSuccessful():
            sys.exit(1)


setup(
    cmdclass={"test": TestCommand},
    name="misspellings_lib",
    version=get_version(),
    url="https://github.com/mazulo/misspellings",
    download_url=f"https://github.com/mazulo/misspellings/tarball/{get_version()}",
    author="Patrick Mazulo",
    author_email="pmazulo@gmail.com",
    description="A tool to detect misspellings with opinionated additions",
    long_description=long_description,
    long_description_content_type="text/markdown",
    package_dir={"": "src"},
    package_data={"misspelling_lib": ["assets/custom.json", "assets/wikipedia.json"]},
    entry_points={"console_scripts": ["misspellings = misspelling_lib.misspellings:main"]},
    install_requires=["typed-argument-parser==1.7.2", "rich==12.6.0"],
    keywords="check, code, spelling, spellcheck",
    license="MIT License",
    platforms=["POSIX"],
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Environment :: Console",
        "License :: OSI Approved :: GNU General Public License v3 (GPLv3)",
        "Operating System :: OS Independent",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Topic :: Utilities",
    ],
)
